# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fundor_utilities',
 'fundor_utilities.migrations',
 'fundor_utilities.templatetags',
 'fundor_utilities.views',
 'fundor_utilities.views.multiform']

package_data = \
{'': ['*']}

install_requires = \
['django>=3.0.0,<4.0.0', 'openpyxl>=3.0.3,<4.0.0']

setup_kwargs = {
    'name': 'fundor-utilities',
    'version': '1.1.0',
    'description': '',
    'long_description': None,
    'author': 'Fundor333',
    'author_email': 'fundor333@fundor333.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fundor333/fundor_utilities',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from .multiform_mixin import *
from .multiform_process import *
from .multiform_view import *

# Taken from https://gist.github.com/jamesbrobb/748c47f46b9bd224b07f
# Example https://stackoverflow.com/questions/15497693/django-can-class-based-views-accept-two-forms-at-a-time/24011448#24011448
